/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: qbbankselector.h 811 2006-01-20 14:52:36Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef QBANKING_BANKSELECTOR_H
#define QBANKING_BANKSELECTOR_H

#include <qbanking/qbbankselector.ui.h>
#include <qbanking/qbanking.h>


class QBanking;


class QBANKING_API QBBankSelector : protected QBBankSelectorUi {
  Q_OBJECT

private:
  QBanking *_qbanking;
  QString _country;

public:
  QBBankSelector(QBanking *qb,
                 const QString &country=QString("de"),
                 QWidget* parent=0, const char* name=0, WFlags fl=0);
  ~QBBankSelector();

  QString getBankCode();

private slots:
  void slotButtonClicked();
};

#endif

